# fastweixin

#### 介绍
快速使用微信的工具集

#### 软件架构
软件架构说明


#### 安装教程

1.  pip安装
```shell script
pip install fastweixin
```
2.  pip安装（使用阿里云镜像加速）
```shell script
pip install fastweixin -i https://mirrors.aliyun.com/pypi/simple
```


#### 使用说明

1.  demo
```python
import fastweixin
res = fastweixin.login_info('aaa', 'bbb')
```
